--
-- ChatMonitor by Mostly.  All Rights Reserved.
--

-----------Initialize Variables-----------
ChatMonitor = {};
ChatMonitor_Settings = {};
ChatMonitor.isChatMonitorInitialized = false;
ChatMonitor.playerName = "";      
ChatMonitor.TotalCount = 150;
ChatMonitor.CountDown = TotalCount;
ChatMonitor.EndCount = 1;
ChatMonitor.DeciTime = 0;
ChatMonitor.Reset = false;

-----------Constants-----------
ChatMonitor.PLUGIN_NAME 	= "ChatMonitor";
ChatMonitor.PLUGIN_VERSION	= 1.2;
ChatMonitor.PLUGIN_CREDIT	= "Mostly";
ChatMonitor.PLUGIN_TITLE 	= ChatMonitor.PLUGIN_NAME .. string.format(" v%.2f" , ChatMonitor.PLUGIN_VERSION); --.. " (by " ..ChatMonitor.PLUGIN_CREDIT .. ")";

-----------read language file-----------
ChatMonitor.curLocal = string.sub(GetLanguage():upper(), 1,2);
local localeFileName = "Interface/AddOns/ChatMonitor/Locales/ChatMonitor."..string.upper(ChatMonitor.curLocal)..".lua";
local func, err = loadfile(localeFileName);
if (err) then
	dofile("Interface/AddOns/ChatMonitor/Locales/ChatMonitor.EN.lua");
else
	dofile(localeFileName);
end 

-----------Minimap Buttons-----------
function ChatMonitor.MinimapButton_OnClick(this)
    PlaySoundByPath("sound\\interface\\ui_generic_click.mp3");
	if ( ChatMonitorConfig:IsVisible() ) then
		HideUIPanel(ChatMonitorConfig);
	else
		ShowUIPanel(ChatMonitorConfig);
	end
end

function ChatMonitor.MinimapButton_OnEnter(this)
    GameTooltip:SetOwner(this, "ANCHOR_LEFT", 4, 0);
	GameTooltip:SetText(PLUGIN_TITLE, 1, 1, 1);
	GameTooltip:AddLine(UI_MINIMAPBUTTON_MOVE, 0, 0.75, 0.95);
	GameTooltip:Show();
end

-----------Register Events-----------
function ChatMonitor.OnLoad(this)
    SaveVariables("ChatMonitor_Settings");
    this:RegisterEvent("CHAT_MSG_WHISPER");
    this:RegisterEvent("CHAT_MSG_SAY");
    this:RegisterEvent("CHAT_MSG_ZONE"); 
    this:RegisterEvent("CHAT_MSG_GUILD");
    this:RegisterEvent("CHAT_MSG_YELL");
    this:RegisterEvent("CHAT_MSG_COMBAT");
    this:RegisterEvent("VARIABLES_LOADED");
	this:RegisterEvent("UNIT_PORTRAIT_UPDATE"); --used, if it was for some reason impossible to get the playername after variables loaded 
end

--------- <OnEvent> ---------
function ChatMonitor.OnEvent(event, this)
	if (event == "VARIABLES_LOADED") then
  		ChatMonitor.CheckSettingsLoaded();
		if (AddonManager) then
			local addon = {
							name = ChatMonitor.PLUGIN_NAME,
							version = ChatMonitor.PLUGIN_VERSION,
							author = ChatMonitor.PLUGIN_CREDIT,
							description = ChatMonitor_Locales["DESCRIPTION"],
							icon = "Interface/AddOns/ChatMonitor/Textures/cm_normal.tga",
							category = "Information",
							configFrame = ChatMonitorConfig,
							slashCommands = "/chmo",
							miniButton = ChatMonitor_AOMButton
			};
			if (AddonManager.RegisterAddonTable) then
				AddonManager.RegisterAddonTable(addon);
			else
				AddonManager.RegisterAddon(addon.name, addon.description, addon.icon, addon.category, addon.configFrame, addon.slashCommands, addon.miniButton, addon.version, addon.author);
			end;
			HideUIPanel(ChatMonitor_MinimapButton);
		else
        	DEFAULT_CHAT_FRAME:AddMessage(string.format(ChatMonitor_Locales["PLUGINLOADED"], ChatMonitor.PLUGIN_TITLE), 0.5, 0.7, 1.0);
		end;
	elseif ( event == "UNIT_PORTRAIT_UPDATE" and arg1 == "player" ) then
		if ( ChatMonitor.isChatMonitorInitialized ~= true ) then
			ChatMonitor.CheckSettingsLoaded();
		end
	elseif (event == "CHAT_MSG_ZONE" or event == "CHAT_MSG_SAY" or event == "CHAT_MSG_YELL" or event == "CHAT_MSG_GUILD") then
		ChatMonitor.Chat(event,this);
	elseif (event == "CHAT_MSG_WHISPER") then
		ChatMonitor.Whisper(event,this);
	elseif (event == "CHAT_MSG_COMBAT") then
		ChatMonitor.Combat(event,this);
	end
end

--------- <Default Settings> ---------
function ChatMonitor.CheckSettingsLoaded()
    if ( ChatMonitor.isChatMonitorInitialized == true ) then
      return;
    end
         
	ChatMonitor.playerName = UnitName("player");
	if ( ChatMonitor.playerName == nil or ChatMonitor.playerName == "" ) then
		return;
	end
	
	local DefaultSettings = {
    	["KeyWordCheck1"] = false,
    	["KeyWord1"] = "",
    	["KeyWord1Sound"] = "Sound1",
    	["KeyWordCheck2"] = false,
    	["KeyWord2"] = "",
    	["KeyWord2Sound"] = "Sound1",
    	["KeyWordCheck3"] = false,
    	["KeyWord3"] = "",
    	["KeyWord3Sound"] = "Sound1",
    	["KeyWordCheck4"] = false,
    	["KeyWord4"] = "",
    	["KeyWord4Sound"] = "Sound1",
    	["KeyWordCheck5"] = false,
    	["KeyWord5"] = "",
    	["KeyWord5Sound"] = "Sound1",
    	["SayChatCheck"] = false,
    	["ZoneChatCheck"] = false,
    	["GuildChatCheck"] = false,
    	["YellChatCheck"] = false,
    	["WhisperCheck"] = false,
    	["WhisperSound"] = "Sound1", 
    	["CritCheck"] = false,
    	["CritSound"] = ChatMonitor_Locales["DEFAULT"], 
    	["ShowTextCheck"] = false
	};
	
	if(ChatMonitor_Settings[ChatMonitor.playerName] == nil) then
      ChatMonitor_Settings[ChatMonitor.playerName] = {};
	end

	for k,v in pairs(DefaultSettings) do
		if (ChatMonitor_Settings[ChatMonitor.playerName][k] == nil) then
      		ChatMonitor_Settings[ChatMonitor.playerName][k] = v;
		end
	end
	ChatMonitor.isChatMonitorInitialized = true;
	DEFAULT_CHAT_FRAME:AddMessage(string.format(ChatMonitor_Locales["SETTINGSLOADED"], ChatMonitor.PLUGIN_TITLE, ChatMonitor.playerName), 0.5, 0.7, 1.0);
end

-------fill dropdowns---------
function ChatMonitor.KeyWord1DropDownFill()
    local info

	for i=1, 7, 1 do
      info = {};
      info.text = "Sound"..i;
      info.func = ChatMonitor.KeyWord1DropDownClick;
      UIDropDownMenu_AddButton(info);
	end;
end;
function ChatMonitor.KeyWord2DropDownFill()
    local info

	for i=1, 7, 1 do
      info = {};
      info.text = "Sound"..i;
      info.func = ChatMonitor.KeyWord2DropDownClick;
      UIDropDownMenu_AddButton(info);
	end;
end;
function ChatMonitor.KeyWord3DropDownFill()
    local info

	for i=1, 7, 1 do
      info = {};
      info.text = "Sound"..i;
      info.func = ChatMonitor.KeyWord3DropDownClick;
      UIDropDownMenu_AddButton(info);
	end;
end;
function ChatMonitor.KeyWord4DropDownFill()
    local info

	for i=1, 7, 1 do
      info = {};
      info.text = "Sound"..i;
      info.func = ChatMonitor.KeyWord4DropDownClick;
      UIDropDownMenu_AddButton(info);
	end;
end;
function ChatMonitor.KeyWord5DropDownFill()
    local info

	for i=1, 7, 1 do
      info = {};
      info.text = "Sound"..i;
      info.func = ChatMonitor.KeyWord5DropDownClick;
      UIDropDownMenu_AddButton(info);
	end;
end;
function ChatMonitor.WhisperDropDownFill()
    local info

	for i=1, 7, 1 do
      info = {};
      info.text = "Sound"..i;
      info.func = ChatMonitor.WhisperDropDownClick;
      UIDropDownMenu_AddButton(info);
	end;
end;        
function ChatMonitor.CritDropDownFill()
    local info
                
    info = {};
    info.text = ChatMonitor_Locales["DEFAULT"];
    info.func = ChatMonitor.CritDropDownClick;  
    UIDropDownMenu_AddButton(info);
	for i=1, 7, 1 do
      info = {};
      info.text = "Sound"..i;
      info.func = ChatMonitor.CritDropDownClick;
      UIDropDownMenu_AddButton(info);
	end;
end;

-------dropdowns clicked---------
function ChatMonitor.KeyWord1DropDownClick(button)
  UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord1DropDown, button:GetText());
end;
function ChatMonitor.KeyWord2DropDownClick(button)
  UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord2DropDown, button:GetText());
end;
function ChatMonitor.KeyWord3DropDownClick(button)
  UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord3DropDown, button:GetText());
end;
function ChatMonitor.KeyWord4DropDownClick(button)
  UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord4DropDown, button:GetText());
end;
function ChatMonitor.KeyWord5DropDownClick(button)
  UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord5DropDown, button:GetText());
end;
function ChatMonitor.WhisperDropDownClick(button)
  UIDropDownMenu_SetSelectedName(ChatMonitorConfig_WhisperDropDown, button:GetText());
end;  
function ChatMonitor.CritDropDownClick(button)
  UIDropDownMenu_SetSelectedName(ChatMonitorConfig_CritDropDown, button:GetText());
end;

---------play preview sounds--------
function ChatMonitor.KeyWord1PlaySound()
  local sound = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord1DropDown);
  PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..sound..".mp3");
end;
function ChatMonitor.KeyWord2PlaySound()
  local sound = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord2DropDown);
  PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..sound..".mp3");
end;
function ChatMonitor.KeyWord3PlaySound()
  local sound = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord3DropDown);
  PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..sound..".mp3");
end;
function ChatMonitor.KeyWord4PlaySound()
  local sound = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord4DropDown);
  PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..sound..".mp3");
end;
function ChatMonitor.KeyWord5PlaySound()
  local sound = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord5DropDown);
  PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..sound..".mp3");
end;
function ChatMonitor.WhisperPlaySound()
  local sound = UIDropDownMenu_GetText(ChatMonitorConfig_WhisperDropDown);
  PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..sound..".mp3");
end;  
function ChatMonitor.CritPlaySound()
  local sound = UIDropDownMenu_GetText(ChatMonitorConfig_CritDropDown);
  if(sound == ChatMonitor_Locales["DEFAULT"]) then   
  	PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/crit.mp3");
  else
  	PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..sound..".mp3");
  end
end;

-----------Show Config Window-----------
function ChatMonitor.OnShow()
  --fill window with current settings.
	
    ChatMonitorConfigTitleFrame_Title:SetText(ChatMonitor.PLUGIN_TITLE);  
	ChatMonitorConfig_Save:SetText(ChatMonitor_Locales["SAVE"]);
    ChatMonitorConfigBackdropFrame_SettingsInfo:SetText(string.format(ChatMonitor_Locales["SETTINGSFORCHAR"], ChatMonitor.playerName));
    ChatMonitorConfigBackdropFrame_TitleKeywords:SetText(ChatMonitor_Locales["KEYWORDS"]);
    
	ChatMonitorConfig_KeyWordCheck1:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck1"]);
	ChatMonitorConfig_KeyWord1:SetText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord1"]);
	ChatMonitorConfig_KeyWord1Play:SetText(ChatMonitor_Locales["PLAY"]);
	UIDropDownMenu_SetWidth(ChatMonitorConfig_KeyWord1DropDown, 65);
    UIDropDownMenu_Initialize(ChatMonitorConfig_KeyWord1DropDown, ChatMonitor.KeyWord1DropDownFill);
    UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord1DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord1Sound"]);
    UIDropDownMenu_SetText(ChatMonitorConfig_KeyWord1DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord1Sound"]);

	ChatMonitorConfig_KeyWordCheck2:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck2"]);
	ChatMonitorConfig_KeyWord2:SetText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord2"]);
	ChatMonitorConfig_KeyWord2Play:SetText(ChatMonitor_Locales["PLAY"]);
	UIDropDownMenu_SetWidth(ChatMonitorConfig_KeyWord2DropDown, 65);
    UIDropDownMenu_Initialize(ChatMonitorConfig_KeyWord2DropDown, ChatMonitor.KeyWord2DropDownFill);
    UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord2DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord2Sound"]);
    UIDropDownMenu_SetText(ChatMonitorConfig_KeyWord2DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord2Sound"]);

	ChatMonitorConfig_KeyWordCheck3:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck3"]);
	ChatMonitorConfig_KeyWord3:SetText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord3"]);
	ChatMonitorConfig_KeyWord3Play:SetText(ChatMonitor_Locales["PLAY"]);
	UIDropDownMenu_SetWidth(ChatMonitorConfig_KeyWord3DropDown, 65);
    UIDropDownMenu_Initialize(ChatMonitorConfig_KeyWord3DropDown, ChatMonitor.KeyWord3DropDownFill);
    UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord3DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord3Sound"]);
    UIDropDownMenu_SetText(ChatMonitorConfig_KeyWord3DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord3Sound"]);

	ChatMonitorConfig_KeyWordCheck4:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck4"]);
	ChatMonitorConfig_KeyWord4:SetText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord4"]);
	ChatMonitorConfig_KeyWord4Play:SetText(ChatMonitor_Locales["PLAY"]);
	UIDropDownMenu_SetWidth(ChatMonitorConfig_KeyWord4DropDown, 65);
    UIDropDownMenu_Initialize(ChatMonitorConfig_KeyWord4DropDown, ChatMonitor.KeyWord4DropDownFill);
    UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord4DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord4Sound"]);
    UIDropDownMenu_SetText(ChatMonitorConfig_KeyWord4DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord4Sound"]);

	ChatMonitorConfig_KeyWordCheck5:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck5"]);
	ChatMonitorConfig_KeyWord5:SetText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord5"]);
	ChatMonitorConfig_KeyWord5Play:SetText(ChatMonitor_Locales["PLAY"]);
	UIDropDownMenu_SetWidth(ChatMonitorConfig_KeyWord5DropDown, 65);
    UIDropDownMenu_Initialize(ChatMonitorConfig_KeyWord5DropDown, ChatMonitor.KeyWord5DropDownFill);
    UIDropDownMenu_SetSelectedName(ChatMonitorConfig_KeyWord5DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord5Sound"]);
    UIDropDownMenu_SetText(ChatMonitorConfig_KeyWord5DropDown, ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord5Sound"]);

    ChatMonitorConfigBackdropFrame_TitleChats:SetText(ChatMonitor_Locales["CHATS"]);
	ChatMonitorConfigBackdropFrame_SayChatCheckText:SetText(ChatMonitor_Locales["SAYCHAT"]);
	ChatMonitorConfig_SayChatCheck:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["SayChatCheck"]);
	ChatMonitorConfigBackdropFrame_ZoneChatCheckText:SetText(ChatMonitor_Locales["ZONECHAT"]);
	ChatMonitorConfig_ZoneChatCheck:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["ZoneChatCheck"]);
	ChatMonitorConfigBackdropFrame_GuildChatCheckText:SetText(ChatMonitor_Locales["GUILDCHAT"]);
	ChatMonitorConfig_GuildChatCheck:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["GuildChatCheck"]);
	ChatMonitorConfigBackdropFrame_YellChatCheckText:SetText(ChatMonitor_Locales["YELLCHAT"]);
	ChatMonitorConfig_YellChatCheck:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["YellChatCheck"]);

    ChatMonitorConfigBackdropFrame_TitleOther:SetText(ChatMonitor_Locales["OTHER"]);
    
	ChatMonitorConfig_SayTextCheck:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["ShowTextCheck"]);
	ChatMonitorConfigBackdropFrame_ShowTextText:SetText(ChatMonitor_Locales["SHOWKEYWORD"]);

	ChatMonitorConfig_WhisperCheck:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["WhisperCheck"]);
	ChatMonitorConfigBackdropFrame_WhisperCheckText:SetText(ChatMonitor_Locales["WHISPER"]);
	ChatMonitorConfig_WhisperPlay:SetText(ChatMonitor_Locales["PLAY"]);
	UIDropDownMenu_SetWidth(ChatMonitorConfig_WhisperDropDown, 65);
    UIDropDownMenu_Initialize(ChatMonitorConfig_WhisperDropDown, ChatMonitor.WhisperDropDownFill);
    UIDropDownMenu_SetSelectedName(ChatMonitorConfig_WhisperDropDown, ChatMonitor_Settings[ChatMonitor.playerName]["WhisperSound"]);
    UIDropDownMenu_SetText(ChatMonitorConfig_WhisperDropDown, ChatMonitor_Settings[ChatMonitor.playerName]["WhisperSound"]);  

	ChatMonitorConfig_CritCheck:SetChecked(ChatMonitor_Settings[ChatMonitor.playerName]["CritCheck"]);
	ChatMonitorConfigBackdropFrame_CritCheckText:SetText(ChatMonitor_Locales["CRITICAL"]);
	ChatMonitorConfig_CritPlay:SetText(ChatMonitor_Locales["PLAY"]);
	UIDropDownMenu_SetWidth(ChatMonitorConfig_CritDropDown, 65);
    UIDropDownMenu_Initialize(ChatMonitorConfig_CritDropDown, ChatMonitor.CritDropDownFill);
    UIDropDownMenu_SetSelectedName(ChatMonitorConfig_CritDropDown, ChatMonitor_Settings[ChatMonitor.playerName]["CritSound"]);
    UIDropDownMenu_SetText(ChatMonitorConfig_CritDropDown, ChatMonitor_Settings[ChatMonitor.playerName]["CritSound"]);
end

-----------SaveSettings-----------
function ChatMonitor.SaveSettings() 
	local NewSettings = {
    	["KeyWordCheck1"] = ChatMonitorConfig_KeyWordCheck1:IsChecked(),
    	["KeyWord1"] = ChatMonitorConfig_KeyWord1:GetText(),
    	["KeyWord1Sound"] = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord1DropDown),
    	["KeyWordCheck2"] = ChatMonitorConfig_KeyWordCheck2:IsChecked(),
    	["KeyWord2"] = ChatMonitorConfig_KeyWord2:GetText(),
    	["KeyWord2Sound"] = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord2DropDown),
    	["KeyWordCheck3"] = ChatMonitorConfig_KeyWordCheck3:IsChecked(),
    	["KeyWord3"] = ChatMonitorConfig_KeyWord3:GetText(),
    	["KeyWord3Sound"] = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord3DropDown),
    	["KeyWordCheck4"] = ChatMonitorConfig_KeyWordCheck4:IsChecked(),
    	["KeyWord4"] = ChatMonitorConfig_KeyWord4:GetText(),
    	["KeyWord4Sound"] = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord4DropDown),
    	["KeyWordCheck5"] = ChatMonitorConfig_KeyWordCheck5:IsChecked(),
    	["KeyWord5"] = ChatMonitorConfig_KeyWord5:GetText(),
    	["KeyWord5Sound"] = UIDropDownMenu_GetText(ChatMonitorConfig_KeyWord5DropDown),
    	["SayChatCheck"] = ChatMonitorConfig_SayChatCheck:IsChecked(),
    	["ZoneChatCheck"] = ChatMonitorConfig_ZoneChatCheck:IsChecked(),
    	["GuildChatCheck"] = ChatMonitorConfig_GuildChatCheck:IsChecked(),
    	["YellChatCheck"] = ChatMonitorConfig_YellChatCheck:IsChecked(),
    	["WhisperCheck"] = ChatMonitorConfig_WhisperCheck:IsChecked(),
    	["WhisperSound"] = UIDropDownMenu_GetText(ChatMonitorConfig_WhisperDropDown),
    	["CritCheck"] = ChatMonitorConfig_CritCheck:IsChecked(),
    	["CritSound"] = UIDropDownMenu_GetText(ChatMonitorConfig_CritDropDown),
    	["ShowTextCheck"] = ChatMonitorConfig_SayTextCheck:IsChecked()
	};

	for k,v in pairs(NewSettings) do
      	ChatMonitor_Settings[ChatMonitor.playerName][k] = v;
	end
	
	DEFAULT_CHAT_FRAME:AddMessage(string.format(ChatMonitor_Locales["SETTINGSSAVED"], ChatMonitor.PLUGIN_TITLE, ChatMonitor.playerName), 0.5, 0.7, 1.0);
end

-----------Handle Tooltips-----------
function ChatMonitor.Tooltip(this, type)
    GameTooltip:SetOwner(this, "ANCHOR_RIGHT", 4, 0);
	if(type=="checkbox") then
		GameTooltip:SetText(ChatMonitor_Locales["CHECKBOXTOOLTIP"], 0, 0.75, 0.95);
	elseif(type=="keyword") then
		GameTooltip:SetText(ChatMonitor_Locales["KEYWORDTOOLTIP"], 0, 0.75, 0.95);
	elseif(type=="play") then
		GameTooltip:SetText(ChatMonitor_Locales["PLAYTOOLTIP"], 0, 0.75, 0.95); 
	elseif(type=="save") then
		GameTooltip:SetText(ChatMonitor_Locales["SAVETOOLTIP"], 0, 0.75, 0.95);
	end
	GameTooltip:Show();
end

-----------Check Chat ------------------
function ChatMonitor.Chat(event,this)
	if(ChatMonitor.isChatMonitorInitialized) then
		local docheck = false;
		if(event == "CHAT_MSG_SAY" and ChatMonitor_Settings[ChatMonitor.playerName]["SayChatCheck"]) then
			docheck = true;    
		elseif(event == "CHAT_MSG_ZONE" and ChatMonitor_Settings[ChatMonitor.playerName]["ZoneChatCheck"]) then
			docheck = true; 
		elseif(event == "CHAT_MSG_GUILD" and ChatMonitor_Settings[ChatMonitor.playerName]["GuildChatCheck"]) then
			docheck = true;                                                             
		elseif(event == "CHAT_MSG_YELL" and ChatMonitor_Settings[ChatMonitor.playerName]["YellChatCheck"]) then
			docheck = true;
		end
		if (docheck) then
			local var = string.lower(arg1);
  
  			if(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck1"] and (ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord1"] ~= nil or ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord1"] ~= "")) then
  				if(string.find(var,string.lower(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord1"])) ~= nil) then
    				PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord1Sound"]..".mp3");
    				ChatMonitor.WarningText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord1"]);
  				end
  			end 
  			if(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck2"] and (ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord2"] ~= nil or ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord2"] ~= "")) then
  				if(string.find(var,string.lower(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord2"])) ~= nil) then
    				PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord2Sound"]..".mp3");
    				ChatMonitor.WarningText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord2"]); 
  				end
  			end   
  			if(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck3"] and (ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord3"] ~= nil or ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord3"] ~= "")) then
  				if(string.find(var,string.lower(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord3"])) ~= nil) then
    				PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord3Sound"]..".mp3");
    				ChatMonitor.WarningText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord3"]);
  				end
  			end
  			if(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck4"] and (ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord4"] ~= nil or ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord4"] ~= "")) then
  				if(string.find(var,string.lower(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord4"])) ~= nil) then
    				PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord4Sound"]..".mp3");
    				ChatMonitor.WarningText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord4"]);
  				end
  			end
  			if(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWordCheck5"] and (ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord5"] ~= nil or ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord5"] ~= "")) then
  				if(string.find(var,string.lower(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord5"])) ~= nil) then
    				PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord5Sound"]..".mp3");
    				ChatMonitor.WarningText(ChatMonitor_Settings[ChatMonitor.playerName]["KeyWord5"]);
  				end
  			end
  		end
  	end
end

-----------do whisper ------------------
function ChatMonitor.Whisper(event,this)
	if(ChatMonitor.isChatMonitorInitialized) then
  		if(ChatMonitor_Settings[ChatMonitor.playerName]["WhisperCheck"]) then
  			PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..ChatMonitor_Settings[ChatMonitor.playerName]["WhisperSound"]..".mp3");
  		end
  	end
end            

-----------do combat ------------------
function ChatMonitor.Combat(event,this)
	if(ChatMonitor.isChatMonitorInitialized) then
  		if(ChatMonitor_Settings[ChatMonitor.playerName]["CritCheck"]) then
  			local var = string.lower(arg1);
  			if(string.find(var,"kritisch") ~= nil) then  
  				if(ChatMonitor_Settings[ChatMonitor.playerName]["CritSound"] == ChatMonitor_Locales["DEFAULT"]) then   
  					PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/crit.mp3");
  				else
  					PlaySoundByPath("Interface/AddOns/ChatMonitor/Sound/"..ChatMonitor_Settings[ChatMonitor.playerName]["CritSound"]..".mp3");
  				end
  			end
  		end
  	end
end

-----------show WarningText-----------
function ChatMonitor.WarningText(warningtext)
	if(ChatMonitor_Settings[ChatMonitor.playerName]["ShowTextCheck"]) then
		ChatMonitor_WarningText:SetText("|cffff9900"..warningtext);
		ChatMonitor.FadeFired = true;
		ChatMonitor.Reset = true;
		ChatMonitor_WarningFrame:SetAlpha(1);
	end
end

-----------fade WarningText-----------
function ChatMonitor.Warning_Tick()
	if ChatMonitor.CountDown >= ChatMonitor.EndCount then
		ChatMonitor.DeciTime = ChatMonitor.CountDown/ChatMonitor.TotalCount;
		if ChatMonitor.DeciTime <= 0.5 then
			ChatMonitor.DeciTime = ChatMonitor.DeciTime*2;
			ChatMonitor_WarningFrame:SetAlpha(ChatMonitor.DeciTime);
		end
	else
		ChatMonitor.FadeFired = false;
		ChatMonitor.CountDown = ChatMonitor.TotalCount;
		ChatMonitor_WarningFrame:SetAlpha(0);
	end
	if ChatMonitor.Reset then
		ChatMonitor.CountDown = ChatMonitor.TotalCount;
		ChatMonitor_WarningFrame:SetAlpha(1);
		ChatMonitor.Reset = false;
	else
		ChatMonitor.CountDown = ChatMonitor.CountDown - 1;
	end
end

-----------slash command-----------
function ChatMonitor.Slashfunction(box,msg)
	if ( ChatMonitorConfig:IsVisible() ) then
		HideUIPanel(ChatMonitorConfig);
	else
		ShowUIPanel(ChatMonitorConfig);
	end
end

SLASH_CMToggle1 = "/chmo";
SlashCmdList["CMToggle"] = ChatMonitor.Slashfunction;